==> eventviews-23.04.1-1-armv7h.pkg.tar.xz: usr/lib/cmake/KPim5EventViews/KPim5EventViewsConfig.cmake <==
# SPDX-FileCopyrightText: none
# SPDX-License-Identifier: BSD-3-Clause

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimEventViewsConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5EventViews" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Akonadi "5.23.1")
find_dependency(KPim5CalendarSupport "5.23.1")
find_dependency(KF5CalendarCore "5.100.0")
find_dependency(KPim5CalendarUtils "5.23.1")
find_dependency(KPim5AkonadiCalendar "5.23.1")

if (FALSE)
    message(WARNING "\n"
                    "************* DEPRECATION WARNING *************\n"
		    "Using find_package(KF5EventViews) and KF5::EventViews targets is deprecated. "
		    "Please use find_package(KPim5EventViews) and KPim5::EventViews instead. This backwards "
                    "compatibility will be removed in the next major version.\n"
                    "***********************************************\n")
endif()

include("${CMAKE_CURRENT_LIST_DIR}/KPim5EventViewsTargets.cmake")

==> eventviews-23.08.0-1-armv7h.pkg.tar.xz: usr/lib/cmake/KPim5EventViews/KPim5EventViewsConfig.cmake <==
# SPDX-FileCopyrightText: none
# SPDX-License-Identifier: BSD-3-Clause

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimEventViewsConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5EventViews" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Akonadi "5.24.0")
find_dependency(KPim5CalendarSupport "5.24.0")
find_dependency(KF5CalendarCore "5.105.0")
find_dependency(KPim5CalendarUtils "5.24.0")
find_dependency(KPim5AkonadiCalendar "5.24.0")
include("${CMAKE_CURRENT_LIST_DIR}/KPim5EventViewsTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KPim5EventViewsQchTargets.cmake")
